@@ -81,6 +81,13 @@ fn from_iter() {
     );
 }
 
+#[wasm_bindgen_test]
+fn extend() {
+    let mut array = array!["a", "b"];
+    array.extend(vec![JsValue::from("c"), JsValue::from("d")]);
+    assert_eq!(array, array!["a", "b", "c", "d"]);
+}
+
 #[wasm_bindgen_test]
 fn to_vec() {
     let array = vec![JsValue::from("a"), JsValue::from("b"), JsValue::from("c")]
@@ -587,6 +594,15 @@ fn Int32Array_view_mut_raw() {
     test_array_view_mut_raw(js_sys::Int32Array::view_mut_raw, i32::from, JsValue::from);
 }
 
+#[wasm_bindgen_test]
+fn BigInt64Array_view_mut_raw() {
+    test_array_view_mut_raw(
+        js_sys::BigInt64Array::view_mut_raw,
+        i64::from,
+        JsValue::from,
+    );
+}
+
 #[wasm_bindgen_test]
 fn Uint8Array_view_mut_raw() {
     test_array_view_mut_raw(js_sys::Uint8Array::view_mut_raw, u8::from, JsValue::from);
@@ -611,6 +627,15 @@ fn Uint32Array_view_mut_raw() {
     test_array_view_mut_raw(js_sys::Uint32Array::view_mut_raw, u32::from, JsValue::from);
 }
 
+#[wasm_bindgen_test]
+fn BigUint64Array_view_mut_raw() {
+    test_array_view_mut_raw(
+        js_sys::BigUint64Array::view_mut_raw,
+        u64::from,
+        JsValue::from,
+    );
+}
+
 #[wasm_bindgen_test]
 fn Float32Array_view_mut_raw() {
     test_array_view_mut_raw(js_sys::Float32Array::view_mut_raw, f32::from, JsValue::from);
